.. Written by Konrad Hinsen
.. License: CC-BY 3.0

The API common to all models
============================

.. automodule:: mosaic.api
   :members:

The immutable model
===================

.. automodule:: mosaic.immutable_model

The mutable model
=================

.. automodule:: mosaic.mutable_model

The array model
===============

.. automodule:: mosaic.array_model

HDF5 I/O
========

.. automodule:: mosaic.hdf5
   :members:

XML I/O
=======

.. automodule:: mosaic.xml_io
   :members:

